<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>EllipseCPP</name>
    <message>
        <source>&amp;Full Ellipse with Center, Point, Ratio</source>
        <translation type="vanished">&amp;Elipsa so Stredom, Vrcholmi/ Polomermi</translation>
    </message>
    <message>
        <location filename="../EllipseCPPInit.js" line="+2"/>
        <source>&amp;Ellipse (Center, Point, Ratio)</source>
        <translation>&amp;Elipsa (Stred, Bod, Pomer)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw full ellipse from center, major point and ratio</source>
        <translation>Nakreslite elipsu so stredovým bodom, vrcholmi/polomermi a uhlami</translation>
    </message>
</context>
</TS>
